selectiontools.Lineage
======================

.. abjad-lineage:: abjad.tools.selectiontools.Lineage.Lineage

.. autoclass:: abjad.tools.selectiontools.Lineage.Lineage

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.Lineage.Lineage.component
      ~abjad.tools.selectiontools.Lineage.Lineage.get_duration
      ~abjad.tools.selectiontools.Lineage.Lineage.get_spanners
      ~abjad.tools.selectiontools.Lineage.Lineage.get_vertical_moment_at
      ~abjad.tools.selectiontools.Lineage.Lineage.__add__
      ~abjad.tools.selectiontools.Lineage.Lineage.__contains__
      ~abjad.tools.selectiontools.Lineage.Lineage.__eq__
      ~abjad.tools.selectiontools.Lineage.Lineage.__format__
      ~abjad.tools.selectiontools.Lineage.Lineage.__getitem__
      ~abjad.tools.selectiontools.Lineage.Lineage.__len__
      ~abjad.tools.selectiontools.Lineage.Lineage.__ne__
      ~abjad.tools.selectiontools.Lineage.Lineage.__radd__
      ~abjad.tools.selectiontools.Lineage.Lineage.__repr__

Bases
-----

- :py:class:`selectiontools.SimultaneousSelection <abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection>`

- :py:class:`selectiontools.Selection <abjad.tools.selectiontools.Selection.Selection>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.selectiontools.Lineage.Lineage.component
   :noindex:

Methods
-------

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.get_spanners
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.get_vertical_moment_at
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Lineage.Lineage.__repr__
   :noindex:
